<?php
// $Id: views_attach_plugin_display_node_content.inc,v 1.1.2.7.2.2 2009/06/03 23:05:41 crell Exp $

/**
 * The plugin that handles node-attached views.
 */
class views_attach_plugin_display_node_content extends views_plugin_display {
  function option_definition () {
    $options = parent::option_definition();

    $options['types'] = array('default' => array());
    $options['modes'] = array('default' => array('full'));
    $options['default_argument'] = array('default' => '');
    $options['show_title'] = 0;

    return $options;
  }

  /**
   * Provide the summary for page options in the views UI.
   *
   * This output is returned as an array.
   */
  function options_summary(&$categories, &$options) {
    // It is very important to call the parent function here:
    parent::options_summary($categories, $options);

    $categories['node_content'] = array(
      'title' => t('Node content settings'),
    );

    $types = $this->get_option('types');
    if (empty($types)) {
      $types = array('story');
    }

    $options['types'] = array(
      'category' => 'node_content',
      'title' => t('Node types'),
      'value' => implode(', ', $types),
    );

    $used_modes = $this->get_option('modes');
    // Get the human readable names.
    $modes = views_attach_build_modes();
    foreach ($used_modes as $mode) {
      $display_modes[] = $modes[$mode];
    }
    $options['modes'] = array(
      'category' => 'node_content',
      'title' => t('Build modes'),
      'value' => implode(', ', $display_modes),
    );

    $weight = $this->get_option('weight');
    if (empty($weight)) {
      $weight = 10;
    }

    //TODO: rename "argument" to "arguments string"?
    $default_argument = $this->get_option('default_argument');
    $options['default_argument'] = array(
      'category' => 'node_content',
      'title' => t('Default argument'),
      'value' => empty($default_argument) ? t('None') : check_plain($default_argument),
    );

    $options['show_title'] = array(
      'category' => 'node_content',
      'title' => t('Show title'),
      'value' => $this->get_option('show_title') ? t('Yes') : t('No'),
    );
  }

  /**
   * Provide the default form for setting options.
   */
  function options_form(&$form, &$form_state) {
    // It is very important to call the parent function here:
    parent::options_form($form, $form_state);

    switch ($form_state['section']) {
      case 'types':
        $form['#title'] .= t('Node types');
        $form['types'] = array(
          '#type' => 'checkboxes',
          '#multiple' => TRUE,
          '#required' => TRUE,
          '#title' => t("Embed this display in the following node types"),
          '#options' => node_get_types('names'),
          '#default_value' => $this->get_option('types'),
        );
        break;

      case 'modes':
        $form['#title'] .= t('Build modes');
        $form['modes'] = array(
          '#type' => 'checkboxes',
          '#title' => t("Embed this display in the following build modes"),
          '#options' => views_attach_build_modes(),
          '#default_value' => $this->get_option('modes'),
         );
         break;

      case 'default_argument':
        $form['#title'] .= t('Default argument');
        $form['default_argument'] = array(
          '#type' => 'textfield',
          '#default_value' => $this->get_option('default_argument'),
          '#description' => t('Separate arguments with "/".'),
        );
        // Add the token help to the form.
        $form['help'] = array(
          '#value' => t('You may use token replacement to provide arguments based on the node. Token replacements require that NID is the first argument of the URL for the view.') . theme('token_help', 'node'),
        );
        break;

      case 'show_title':
        $form['#title'] .= t('Show title');
        $form['show_title'] = array(
          '#type' => 'checkbox',
          '#title' => t('Show the title of the view above the attached view.'),
          '#default_value' => $this->get_option('show_title'),
        );
        break;
    }

  }

  function options_submit($form, &$form_state) {
    // It is very important to call the parent function here:
    parent::options_submit($form, $form_state);
    switch ($form_state['section']) {
      case 'types':
        $this->set_option('types', array_filter($form_state['values']['types']));
        break;
      case 'modes':
        $this->set_option('modes', array_values(array_filter($form_state['values']['modes'])));
        break;
      case 'default_argument':
        $this->set_option('default_argument', $form_state['values']['default_argument']);
        break;
      case 'show_title':
        $this->set_option('show_title', $form_state['values']['show_title']);
        break;
    }
  }
  /**
   * We have to run token replacement before the arguments are used.
   */
   function pre_execute() {
     // Call the parent setup function so we do not lose data.
     parent::pre_execute();
     $args = $this->view->args;
     $token_string = $this->view->display_handler->get_option('default_argument');
     if (empty($args) || empty($token_string)) {
       return;
     }
     $node_types = $this->view->display_handler->get_option('types');

     $node = node_load($args[0]);
     if (!in_array($node->type, $node_types)) {
       return;
     }
     // Now do the token replacement.
     $token_values = views_attach_get_arguments_from_token_string($token_string, 'node', $node);
     $new_args = array();
     // We have to be careful to only replace arguments that have tokens.
     foreach ($token_values as $key => $value) {
       $new_args[$key] = $value;
     }
     $this->view->args = $new_args;
   }

  /**
   * The display block handler returns the structure necessary for a block.
   */
  function execute() {
    // Prior to this being called, the $view should already be set to this
    // display, and arguments should be set on the view.
    $data = $this->view->render();
    if (!empty($this->view->result) || $this->get_option('empty') || !empty($this->view->style_plugin->definition['even empty'])) {
      return $data;
    }
  }

  /**
   * Block views do not use exposed widgets.
   */
  function uses_exposed() { return FALSE; }
}
