<?php
// $Id: views_attach_plugin_display_profile.inc,v 1.1.2.1.2.3 2009/06/03 23:05:41 crell Exp $

/**
 * The plugin that handles a user profile.
 */
class views_attach_plugin_display_profile extends views_plugin_display {
  function option_definition () {
    $options = parent::option_definition();

    $options['weight'] = array('default' => 10);
    $options['category'] = array('default' => NULL);
    $options['default_argument'] = array('default' => '');

    return $options;
  }

  /**
   * Provide the summary for page options in the views UI.
   *
   * This output is returned as an array.
   */
  function options_summary(&$categories, &$options) {
    // It is very important to call the parent function here:
    parent::options_summary($categories, $options);

    $categories['profile'] = array(
      'title' => t('Profile settings'),
    );

    $category = $this->get_option('category');
    if (empty($category)) {
      $category = t('Default');
    }

    $options['category'] = array(
      'category' => 'profile',
      'title' => t('Category'),
      'value' => $category,
    );

    $weight = $this->get_option('weight');
    if (empty($weight)) {
      $weight = 10;
    }

    $options['weight'] = array(
      'category' => 'profile',
      'title' => t('Weight'),
      'value' => $weight,
    );

    $default_argument = $this->get_option('default_argument');
    $options['default_argument'] = array(
      'category' => 'profile',
      'title' => t('Default argument'),
      'value' => empty($default_argument) ? t('None') : check_plain($default_argument),
    );
  }

  /**
   * Provide the default form for setting options.
   */
  function options_form(&$form, &$form_state) {
    // It is very important to call the parent function here:
    parent::options_form($form, $form_state);

    switch ($form_state['section']) {
      case 'weight':
        $form['#title'] .= t('Weight');
        $form['weight'] = array(
          '#type' => 'weight',
          '#description' => t('The position of this view in relation to other profile elements.'),
          '#default_value' => $this->get_option('weight'),
        );
        break;
      case 'category':
        $form['#title'] .= t('Category');
        $form['category'] = array(
          '#type' => 'textfield',
          '#description' => t('The name of the profile tab this view should be listed in. If empty, it will be displayed on the main profile tab.'),
          '#default_value' => $this->get_option('category'),
        );
        break;
      case 'default_argument':
        $form['#title'] .= t('Default argument');
        $form['default_argument'] = array(
          '#type' => 'textfield',
          '#default_value' => $this->get_option('default_argument'),
          '#description' => t('Separate arguments with "/".'),
        );
        // Add the token help to the form.
        $form['help'] = array(
          '#value' => '<p>'. t('You may use token replacement to provide arguments based on the user. Token replacements require that UID is the first argument of the URL for the view.') .'</p>'. theme('token_help', 'user'),
        );
        break;
    }
  }

  function options_submit($form, &$form_state) {
    // It is very important to call the parent function here:
    parent::options_submit($form, $form_state);
    switch ($form_state['section']) {
      case 'weight':
        $this->set_option('weight', $form_state['values']['weight']);
        break;
      case 'category':
        $this->set_option('category', $form_state['values']['category']);
        break;
      case 'default_argument':
        $this->set_option('default_argument', $form_state['values']['default_argument']);
        break;
    }
  }

  /**
   * We have to run token replacement before the arguments are used.
   */
   function pre_execute() {
     // Call the parent setup function so we do not lose data.
     parent::pre_execute();
     $args = $this->view->args;
     $token_string = $this->view->display_handler->get_option('default_argument');
     if (empty($args) || empty($token_string)) {
       return;
     }

     if(is_array($args)){
       $user = user_load($args[0]);
     }
     else {
       $user = user_load($args);
     }

      // Now do the token replacement.
     $token_values = views_attach_get_arguments_from_token_string($token_string, 'user', $user);
     $new_args = array();
     // We have to be careful to only replace arguments that have tokens.
     foreach ($token_values as $key => $value) {
       $new_args[$key] = $value;
     }

     $this->view->args = $new_args;
   }

  /**
   * The display block handler returns the structure necessary for a block.
   */
  function execute() {
    // Prior to this being called, the $view should already be set to this
    // display, and arguments should be set on the view.
    $data = $this->view->render();
    if (!empty($this->view->result) || $this->get_option('empty') || !empty($this->view->style_plugin->definition['even empty'])) {
      return $data;
    }
  }

  /**
   * Block views do not use exposed widgets.
   */
  function uses_exposed() { return FALSE; }
}
